@@ -6,13 +6,14 @@
 #include <QProcess>
 #include <QtGui/QCloseEvent>
 #include <QSettings>
+//#include <QDebug>
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
 {
     videoyes = true; //so that sdpgen denerates the right file, when presed by itself.
-    sdpyes = false;
+    sdpgenerated = false;
     //cambackyes=false;
     ui->setupUi(this);
     debugclicked = false;
@@ -21,25 +22,21 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->outWind->hide();
     ui->sdpgen->hide();
     ui->stopsream->hide();
-    ui->howtext->hide();
     ui->filesinkname->hide();
     ui->labfilenam->hide();
-    ui->lenswidg->setStyleSheet("QWidget { background-color: rgb(60, 60, 100); }");
-    ui->labcamwarn->setStyleSheet("QLabel {color : black;}");
-    ui->okstream->setStyleSheet("QPushButton {background-color : black; color : white;}");
-    ui->how->setStyleSheet("QPushButton {background-color : black; color : white;}");
-    ui->howtext->setStyleSheet("QTextBrowser {background-color : rgb(223, 223, 223); color : black;}");
     ui->scpframe->setStyleSheet("QWidget { background-color: black;}");
     ui->labscpuser->setStyleSheet("QLabel {color : white;}");
     ui->labscppass->setStyleSheet("QLabel {color : white;}");
     ui->scpsend->setStyleSheet("QPushButton {background-color : white; color : black;}");
     ui->usernam->setStyleSheet("QLineEdit {background-color : white; color : black;}");
     ui->passwrd->setStyleSheet("QLineEdit {background-color : white; color : black;}");
-    ui->lenswidg->hide();
     ui->scpbutton->hide();
     ui->scpframe->hide();
     ui->passwrd->setEchoMode(QLineEdit::Password);
-    helpCounter=0;
+    ui->port1->setValidator(new QIntValidator(0,9999, this));
+    ui->vol->setValidator(new QIntValidator(0,9,this));
+    ui->qcontrol->setValidator(new QIntValidator(0,100,this));
+    helpScreen = true;  //show helpscreen
     ui->qcontrol->hide();
     applySettings();
 }
@@ -49,7 +46,9 @@ MainWindow::~MainWindow()
     delete ui;
 }
 
+
 void MainWindow::makeStream(QString host, bool backcamera, bool video, QString port, QString width, QString height, int outp){
+    QString contextRun;
     QString midbits;
     QString streamout;
     QString qbcam;
@@ -60,28 +59,36 @@ void MainWindow::makeStream(QString host, bool backcamera, bool video, QString p
         if(outp!=3){ //filesink? no
             if(outp==0){//VLC
                 midbits = "dsph264enc ! rtph264pay ! udpsink";
+                contextRun = "Open file in VLC";
             } else if (outp==1){ //Xout
                 midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
+                contextRun = "   from terminal, run: 'sh ~/Desktop/n900Xvideo.sh'";
             } else if (outp==2){//webcam
                 //midbits = "ffmpegcolorspace ! smokeenc ! udpsink";  using jpeg for quality preferences.
                 midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
+                contextRun = "   from terminal, run: 'sh ~/Desktop/n900Webvideo.sh'";
             } else if (outp==4){ //remote file
                 midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
+                contextRun = "   from terminal, run: 'sh ~/Desktop/n900FileSave.sh'\n(Make sure that 'gstreamer0.10-ffmpeg' is installed on remote PC)";
             }
             streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" !"+midbits+" host="+host+" port="+port;
+            notify("Run file on Remote PC: \n"+contextRun, true);
+            //more contextual instruction o how to run the file needed.
+            notify("streaming", false);
         }
         else if(outp==3){ //filesink
             QString filelocation = ui->filesinkname->text();
             streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" ! ffmpegcolorspace ! jpegenc "+Jquality+" ! avimux ! filesink location=/home/user/MyDocs/.videos/"+filelocation+".avi";
+            notify("streaming to "+filelocation, false);
         }
     }
     else if (!video){
         streamout = "gst-launch-0.10 pulsesrc ! audioconvert ! volume volume="+ui->vol->text()+" ! audioresample ! nokiaaacenc ! rtpmp4apay ! udpsink host="+host+" port="+port;
     }
-    ui->outWind->setText("currently streaming.");
+    ui->outWind->setText("...currently streaming...");
     QProcess*proc = new QProcess();
     proc->start(streamout);
-    ui->outWind->append(proc->readAll()); //NOW JUST NEED TO PASS OUTPUT FROM GST-LAUNCH BACK INTO OUTWIND
+    //ui->outWind->append(proc->readAll()); //NOW JUST NEED TO PASS OUTPUT FROM GST-LAUNCH BACK INTO OUTWIND
  }
 
 void MainWindow::write2file(QString path, QString script){
@@ -91,48 +98,63 @@ void MainWindow::write2file(QString path, QString script){
     QTextStream out(&file);
     out << script;
     file.close();
-    ui->outWind->append("Generated");
+    //ui->outWind->append("Generated");
 
     //make executable-----------------doesnt work
-    QStringList arguments;
+    /*QStringList arguments;
     arguments << "-c" << "chmod a+x "+path;
     QProcess* exer = new QProcess(this);
     exer->start("/bin/sh", arguments);
     exer->waitForFinished();
-    exer->terminate();
+    exer->terminate();*/
  }
 
 void MainWindow::on_streambut_clicked()
 {
-    ui->address1->setProperty("enabled", false);ui->port1->setProperty("enabled", false); ui->type1->setProperty("enabled", false); ui->size1->setProperty("enabled", false);
-    ui->camera1->setProperty("enabled", false);ui->custom1->setProperty("enabled",false);ui->outWind->setProperty("enabled", false); ui->debuginfo->setProperty("enabled",false);
-    ui->sdpgen->setProperty("enabled", false); ui->scpbutton->setProperty("enabled", false);ui->vol->setProperty("enabled",false);ui->vidsink->setProperty("enabled",false);
-    ui->stopsream->show(); ui->streambut->hide();
-    ui->tickqual->setProperty("enabled",false);ui->qcontrol->setProperty("enabled",false); ui->filesinkname->setProperty("enabled",false);
-    //cameraselector
-    if(ui->type1->currentIndex()==0 && ui->camera1->currentIndex()==0){
-        cambackyes=true;
-        helpCounter ++;
-        ui->lenswidg->show();
-        if(helpCounter > 1){ streamProcess1();}
-    }
-    else {
-        cambackyes=false;
-        streamProcess1();
+    if(!alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text())){          //if file hasnt been generated previously, then flag.
+        sdpgenerated = false;
+        notify("Please generate and send a new file, then stream", false);
     }
+    else if(alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text())){          //if file hasnt been generated previously, then flag.
+        sdpgenerated = true;
 
+        if(ui->type1->currentIndex()==0 && ui->camera1->currentIndex()==0){  //video and back
+            cambackyes=true; //is it back camera, yes
+            if(helpScreen){
+                helpScreen=false;
+                notify("Please Calibrate Back Camera",false);
+                QString controls = "*Slide open camera lens-cap \n*Wait for Camera app to launch.\n*Soft press the camera button to focus until satisfied\n*Keeping the lens-cap open, close the Camera app\n*Once ready, press Stream button again";
+                notify(controls,true);
+            }
+            else{
+                streamProcess1();
+            }
+        }
+        else {
+            cambackyes=false;
+            streamProcess1();
+        }
+
+    }
 }
 
+
 void MainWindow::writeSettings(){
     QSettings settings("daUser", "tester");
     settings.beginGroup("MainWindow"); //beginWriteArray?
     settings.setValue("address",ui->address1->text());settings.setValue("port",ui->port1->text());
     settings.setValue("type",ui->type1->currentIndex()); settings.setValue("camera",ui->camera1->currentIndex()); settings.setValue("size",ui->size1->currentIndex());
-    settings.setValue("custom",ui->custom1->text()); settings.setValue("user",ui->usernam->text()); settings.setValue("password",ui->passwrd->text());settings.setValue("volume", ui->vol->text());
-    settings.setValue("quality",ui->qcontrol->text());
+    settings.setValue("custom",ui->custom1->text()); settings.setValue("user",ui->usernam->text());settings.setValue("volume", ui->vol->text()); settings.setValue("quality",ui->qcontrol->text());
+    settings.setValue("checked",ui->rempass->checkState());
+    if(ui->rempass->isChecked()){
+        settings.setValue("password",ui->passwrd->text());
+    } else{
+        settings.setValue("password","");
+    }
     settings.endGroup();
 }
 
+
 void MainWindow::applySettings(){
     QSettings settings("daUser", "tester");
     settings.beginGroup("MainWindow");
@@ -140,13 +162,10 @@ void MainWindow::applySettings(){
     ui->size1->setCurrentIndex(settings.value("size").toInt()); ui->camera1->setCurrentIndex(settings.value("camera").toInt());
     ui->custom1->setText(settings.value("custom").toString());ui->usernam->setText(settings.value("user").toString()); ui->passwrd->setText(settings.value("password").toString());
     volumeR = settings.value("volume").toString(); ui->vol->setText(volumeR); ui->qcontrol->setText(settings.value("quality").toString());
+    if(ui->type1->currentIndex()==1){on_type1_activated(1);} else {on_type1_activated(0);}
+
+    if(settings.value("checked")==(Qt::Checked)){ui->rempass->setCheckState(Qt::Checked);} else {ui->rempass->setCheckState(Qt::Unchecked);}
     settings.endGroup();
-    if(ui->type1->currentIndex()==1){
-        on_type1_activated(1);
-    }
-    else {
-        on_type1_activated(0);
-    }
 }
 
 void MainWindow::streamProcess1(){
@@ -157,27 +176,146 @@ void MainWindow::streamProcess1(){
     if(currentsize == "Custom"){
         currentsize = ui->custom1->text();
     }
+    //blanking out windows while streaming
+    ui->stopsream->show(); ui->streambut->hide();
+    showWin(false);
     //splitting the string
     QStringList sized = currentsize.split("x");
     widthnum = sized[0];
     heightnum = sized[1];
     int currOutput = ui->vidsink->currentIndex();
+    //LED
+    ledON(true);
+
     makeStream(hostname,cambackyes,videoyes,portnum,widthnum,heightnum, currOutput);
 }
 
+void MainWindow::showWin(bool hid){
+    ui->address1->setProperty("enabled", hid);ui->port1->setProperty("enabled", hid); ui->type1->setProperty("enabled", hid); ui->size1->setProperty("enabled", hid);
+    ui->camera1->setProperty("enabled", hid);ui->custom1->setProperty("enabled",hid);ui->outWind->setProperty("enabled", hid); ui->debuginfo->setProperty("enabled",hid);
+    ui->sdpgen->setProperty("enabled", hid); ui->scpbutton->setProperty("enabled", hid);ui->vol->setProperty("enabled",hid);ui->vidsink->setProperty("enabled",hid);
+    ui->tickqual->setProperty("enabled",hid);ui->qcontrol->setProperty("enabled",hid); ui->filesinkname->setProperty("enabled",hid);
+}
+
+
+
 void MainWindow::scpSender(QString user, QString pass, QString file){
     QString expectfile = QString("#!/usr/bin/expect -f\nset filename [lindex $argv 0]\nset user [lindex $argv 1]\nset pass [lindex $argv 2]\nset ipadd [lindex $argv 3]\nset timeout -1\nspawn scp $filename $user@$ipadd:/home/$user/Desktop\nexpect {\n%1yes/no)?%1 {exp_send %1yes%2r%1; exp_continue}\n%1*assword:%1 { send %1$pass%2r%1; exp_continue}\neof exit\n}").arg(QChar(0x22),QChar(0x5c));
     write2file("/home/user/.scp",expectfile);
     QProcess*sender1 = new QProcess();
     sender1->start("expect /home/user/.scp "+file+" "+user+" "+pass+" "+ui->address1->text());
     sender1->waitForFinished();
-    ui->outWind->append("Done....check your desktop's desktop");
+    QString output = sender1->readAll();
+    ui->outWind->append(output);
+
+
+
+    //This is the method of updating ssh known hosts, but it doesn't work, and also might update the wrong address at this position.
+    //BAD METHOD. use method below this where it tells user what to delete.
+    /*QStringList args1;
+    args1 << "-c" << "sudo ssh-keygen -R "+ui->address1->text();
+    QProcess*sshgen = new QProcess(this);
+    sshgen->start("/bin/sh", args1);
+    sshgen->waitForFinished();*/
+
+
+    //1. First check if offending an existing key:
+    //2. The check if right hostname
+    //3. Then check if right machine "No route to host"
+    //4. Then right password  "Permission denied, please try again"
+    //5. Then if openssh installed "refused"
+    //6. then correct
+
+    if(output.contains("Offending")){
+        QStringList oo = output.split("Offending");
+        QString oo1 = oo[1];
+        int obeg = oo1.indexOf(QChar(0x02f));       // "/"
+        int oend = oo1.indexOf(QChar(0x03A));       // ":"
+        QString kh = oo1.mid(obeg, (oend-obeg));    // gets /root/.ssh/known_hosts
+        QString ln = oo1.mid(oend+1,1);             // gets line number
+        notify("Remote Host Identification has changed",true);
+        notify("Delete row "+ln+" from file "+kh,false);
+        alreadygen.removeLast();
+    }
+    else if(output.contains("Invalid argument")){
+        notify("Invalid argument.", true);
+        notify("check your input.", false);
+        ui->outWind->clear();
+        alreadygen.removeLast();
+    }
+
+
+    else if(output.contains("resolve hostname")){
+        notify("Invalid Hostname", true);
+        notify("Verify Hostname of remote PC", false);
+        alreadygen.removeLast();
+    }
+
+    else if(output.contains("No route")){
+        notify("Invalid Address",true);
+        notify("Verify IP of remote PC",false);
+        alreadygen.removeLast();
+    }
+    else if(output.contains("denied")){
+        notify("Wrong Username or Password",true);
+        notify("Please check, and try again",false);
+        alreadygen.removeLast();
+    }
+    else if(output.contains("refused")){
+        notify("Connection Refused",true);
+        notify("Please confirm that openssh-server is installed on remote system",false);
+        alreadygen.removeLast();
+    }
+    else if(output.contains("100%")){
+        ui->outWind->clear();
+        ui->outWind->append("Sent....check your Remote PC Desktop\nYou may change Camera, Size, and Quality settings, otherwise hit Stream!");
+        notify("File sent! Check your Desktop", true);
+
+        //Delete generated file after sending. All files are also deleted on exit, but keep in case of app crash.
+        QStringList arguments1;
+        arguments1 << "-c" << "sudo rm -f "+currentFile;
+        QProcess*process2 = new QProcess(this);
+        process2->start("/bin/sh", arguments1);
+        process2->waitForFinished();
+        process2->terminate();
+
+        notify("You may now stream", false);
+        on_debuginfo_clicked(); //closes debug window
+
+    }
+    else {
+        notify("Error: Timed out.",true);
+        notify("Check the Address.", false);
+        alreadygen.removeLast();
+    }
+    //showWin(true);
     sender1->terminate();
 }
 
+
+void MainWindow::notify(QString message, bool bottortop){  //for doing notifications to phone
+    QProcess*warn1 = new QProcess();
+    QString messy="";
+    if(bottortop){         //message
+        messy = QString("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:%1"+message+"%1 uint32:0 string:%1OK%1").arg(QChar(0x22));
+    } else if (!bottortop){ //line
+        messy = QString("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:%1"+message+"%1").arg(QChar(0x22));
+    }
+    warn1->start(messy);
+    warn1->waitForFinished();
+    warn1->close();
+    warn1->terminate();
+}
+
+
 void MainWindow::on_type1_activated(int index) //link on cmera1_activated into this? and then link size_activate into camera1_actiavet?!?!
 {
+    //Show Addres
+    ui->labAddr->show(); ui->address1->show(); ui->labPort->show();; ui->port1->show();
     if(index==1){ //Audio
+        vidoutput= "VLC sdp";
+        ui->sdpgen->setText("Generate "+vidoutput+" file");
+        ui->scpbutton->setText("Send "+vidoutput+" to Linux PC"); //fixes error where audio sdpgen shows webscript instead.
         ui->labCam->hide();
         ui->labsize->hide();
         ui->camera1->hide();
@@ -243,9 +381,17 @@ void MainWindow::on_size1_currentIndexChanged(QString isCustom)
 
 void MainWindow::on_debuginfo_clicked()
 {
-    ui->outWind->show();
-    ui->sdpgen->show();
-    debugclicked = true;
+    if(debugclicked){
+        ui->outWind->hide();
+        ui->sdpgen->hide();
+        ui->scpbutton->hide();
+        debugclicked=false;
+    }else{
+        ui->outWind->show();
+        ui->sdpgen->show();
+        on_vidsink_activated(ui->vidsink->currentIndex()); //to prevent
+        debugclicked = true;
+    }
 }
 
 QString MainWindow::getIP(){
@@ -262,9 +408,9 @@ QString MainWindow::getIP(){
 
 void MainWindow::on_sdpgen_clicked()
 {
-    sdpyes = false;
+    //sdpyes = false;
     QString localip=getIP();
-    ui->outWind->setText("local ip is "+localip);
+    ui->outWind->setText("Local IP is "+localip);
     QString decoder;QString typer;
     int outpp = ui->vidsink->currentIndex();
 
@@ -273,103 +419,126 @@ void MainWindow::on_sdpgen_clicked()
         else if(!videoyes){ typer="audio"; decoder="MP4A-LATM/48000/2";}
         currentFile ="/home/user/MyDocs/n900"+typer+"strm.sdp";
         write2file(currentFile,"v=0\nm="+typer+" "+ui->port1->text()+" RTP/AVP 96\nc=IN IP4 "+localip+"\na=rtpmap:96 "+decoder); //VLC
+
     }
     else if(outpp==1) { //Xout
         currentFile = "/home/user/MyDocs/n900Xvideo.sh";
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+"  ! jpegdec ! autovideosink"); //Xout
+
     }
     else if(outpp==2) { //webcam
         currentFile = "/home/user/MyDocs/n900Webvideo.sh";
         //write2file(currentFile,"gst-launch-0.10 udpsrc port="+ui->port1->text()+" ! smokedec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0");  //webcam
         //Using Jpeg for now, higer quality?
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+"  ! jpegdec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0"); //Xout
+
     }
-    else if(outpp==3) {//filesink
-        ui->outWind->setText("Dont need to generate anything for a filesink.");
+    else if(outpp==3) {//filesink --generate button hidden for this, but just in case.
+        notify("Don't need to generate anything for local file", false);
+        ui->outWind->clear();
+
     }
     else if(outpp==4){//remote filesink
         currentFile = "/home/user/MyDocs/n900FileSave.sh";
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+" ! jpegdec ! ffenc_mpeg2video ! filesink location=/home/"+ui->usernam->text()+"/Desktop/"+ui->filesinkname->text()+".mpg");
+
     }
-    sdpyes=true;
+    //alreadygen.append(outpp) //old integer method
+    notify("Generated",false);
     ui->scpbutton->show();
 }
 
+void MainWindow::ledON(bool led){
+    QString lstream = "";
+    QProcess*ledterm = new QProcess();
+    if(led){ //ON
+        lstream = QString("dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_activate string:%1PatternWebcamActive%1").arg(QChar(0x22));
+        ledterm->start(lstream);
+        ledterm->waitForFinished();
+    }
+    else if (!led){ //OFF
+        lstream = QString("dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:%1PatternWebcamActive%1").arg(QChar(0x22));
+        ledterm->start(lstream);
+        ledterm->waitForFinished();
+        ledterm->terminate();
+    }
+}
+
 void MainWindow::on_stopsream_clicked()
 {
     QProcess*terminator = new QProcess();
-    QProcess*ledterm = new QProcess();
     terminator->start("killall gst-launch-0.10");
     terminator->waitForFinished();
     terminator->terminate();
     //Turn off LED
-    QString lstream = QString("dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:%1PatternWebcamActive%1").arg(QChar(0x22));
-    ledterm->start(lstream);
-    ledterm->waitForFinished();
+    ledON(false);
     //
     ui->outWind->clear();
     ui->outWind->append("Stopped Steaming");
     ui->stopsream->hide();
     ui->streambut->show();
     //making everything visible
-    ui->address1->setProperty("enabled", true);ui->port1->setProperty("enabled", true); ui->type1->setProperty("enabled", true); ui->size1->setProperty("enabled", true);
-    ui->custom1->setProperty("enabled",true);ui->outWind->setProperty("enabled", true); ui->debuginfo->setProperty("enabled",true);ui->camera1->setProperty("enabled", true);
-    ui->sdpgen->setProperty("enabled", true); ui->scpbutton->setProperty("enabled", true);ui->vol->setProperty("enabled",true);ui->vidsink->setProperty("enabled",true);
-    ui->tickqual->setProperty("enabled",true);ui->qcontrol->setProperty("enabled",true);ui->filesinkname->setProperty("enabled",true);
+    showWin(true);
     //
-    ledterm->terminate();
     proc.terminate();//doesn't do anything really
 }
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
    event->ignore();
+
+   //Deletes all generated files
+   QStringList arguments1;
+   arguments1 << "-c" << "sudo rm -f /home/user/MyDocs/n900videostrm.sdp /home/user/MyDocs/n900audiostrm.sdp /home/user/MyDocs/n900Xvideo.sh /home/user/MyDocs/n900Webvideo.sh /home/user/MyDocs/n900FileSave.sh /home/user/.scp";
+   QProcess*process2 = new QProcess(this);
+   process2->start("/bin/sh", arguments1);
+   process2->waitForFinished();
+   process2->terminate();
+
    on_stopsream_clicked();  //closes all stream
    writeSettings();
    event->accept();
 }
 
-void MainWindow::on_how_clicked()
-{
-    ui->howtext->show();
-}
-
-void MainWindow::on_okstream_clicked()
-{
-    ui->lenswidg->resize(QSize::QSize(0,0));
-    on_streambut_clicked();
-}
-
 void MainWindow::on_scpbutton_clicked()
 {
-  ui->outWind->setText("This will only work if your username is the same on the PC: e.g <user>@192.168.2.12:/home/<user>/Desktop");
+  ui->outWind->setText("This will only work if your username is the same on the PC: e.g <user>@+"+ui->address1->text()+":~/Desktop");
   ui->scpframe->show();
 }
 
 void MainWindow::on_scpsend_clicked()
 {
+    alreadygen.append(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text()); //adds generated selection to list.
+    //qDebug() << alreadygen;
     ui->scpsend->setStyleSheet("QPushButton {background-color : rgb(60, 60, 100); color : white;}");
     ui->scpframe->hide();
-    ui->outWind->setText("Sending....\nPlease Wait");
+    //showWin(false);
+    notify("sending....please wait",false);
     scpSender(ui->usernam->text(),ui->passwrd->text(),currentFile);
-    ui->scpsend->setStyleSheet("QPushButton {background-color : white; color : black;}");
+    ui->scpsend->setStyleSheet("QPushButton {background-color : white; color : black;}");    
 }
 
-void MainWindow::on_vidsink_activated(int index)
+void MainWindow::on_vidsink_activated(int index)  //this is messy.
 {
     if(index==3 || index==4){//File
         ui->labfilenam->show();
         ui->filesinkname->show();
         ui->tickqual->show();
+        if(ui->filesinkname->text()==""){
+            notify("Please fill out filename", false);
+        }
         if(index==3){
             ui->sdpgen->hide();
             ui->scpbutton->hide();
             ui->labfilenam->setText("     Filename (/home/user/MyDocs/.videos/):");
             //Hide top row
             ui->address1->hide(); ui->labAddr->hide(); ui->port1->hide(); ui->labPort->hide();
+            ui->outWind->setText("Nothing needed to generate or send. \nPlease fill out name of video and hit Stream.");
+            sdpgenerated = true; //doesnt need to generate one.
+
         }
         if(index==4) {
-            ui->sdpgen->show();
+            //ui->sdpgen->show();
             ui->labfilenam->setText("    Remote Filename:");
             vidoutput="RemoteFilescript";
             ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
@@ -399,8 +568,11 @@ Fix script for front camera + LED shutdown on some devices. ??
 Fix IP address issues
 Add zooming feature
 Ncurses version
-Stream to a file
-Stream to the web as watchdog
+Stream to the web as watchdog --using damion's scripts.
+Add dialog to check whether lens cap still open when exiting.
+Catch error of no filename for File and remotefile before sending.
+Perhaps use sdpyes to check whether file has already been generated, and throw error if address has been changed or something.
+For offending key error in expect, maybe just peform 'ssh-keygen -R hostaddress' to bypass this, rather than let user do this themselves.
 */
 
 void MainWindow::on_tickqual_toggled(bool checked)
@@ -413,3 +585,9 @@ void MainWindow::on_tickqual_toggled(bool checked)
         ui->qcontrol->hide();
     }
 }
+/*Added notifications.
+Removed sdpyes (which did nothing) ----marybe it did!
+You have some global strings widthnum, which aren't used anywhere else. hostname should be used more than once(though updated at generating stage).
+Delete generated files from device upon sending.
+
+*/
