@@ -21,7 +21,7 @@ public:
 
 private:
     Ui::MainWindow *ui;
-    int helpCounter;
+    bool helpScreen;
     QString hostname;
     QString portnum;
     QString widthnum;
@@ -29,11 +29,12 @@ private:
     bool cambackyes;
     bool videoyes;
     QString currentFile;
-    bool sdpyes;
+    bool sdpgenerated;
     QString vidoutput;
     QProcess proc;
     QString volumeR;
     bool debugclicked;
+    QStringList alreadygen; //vidsink and address:port combo. -- implement later.
 
 private slots:
     void on_tickqual_toggled(bool checked);
@@ -42,9 +43,7 @@ private slots:
     void scpSender(QString user, QString pass, QString file);
     void on_scpsend_clicked();
     void on_scpbutton_clicked();
-    void on_okstream_clicked();
     void streamProcess1();
-    void on_how_clicked();
     void on_stopsream_clicked();
     QString getIP();
     void on_sdpgen_clicked();
@@ -55,6 +54,9 @@ private slots:
     void on_streambut_clicked();
     void makeStream(QString host, bool backcamera, bool video, QString port, QString width, QString height, int output);
     void write2file(QString path, QString script);
+    void notify(QString message, bool messageorline);
+    void ledON(bool yepper);
+    void showWin(bool hid);
 };
 
 #endif // MAINWINDOW_H
